#include <imsls.h>

int main()
{
    int      n_rows = 4;
    int      n_columns = 4;
    int      df1, df2;
    float    table[16]  =  {821.0, 112.0, 85.0, 35.0, 
                            116.0, 494.0, 145.0, 27.0, 
                            72.0, 151.0, 583.0, 87.0, 
                            43.0, 34.0, 106.0, 331.0};
    float    p_value1, p_value2, chi_squared, g_squared;
    float    *expected, *chi_squared_contributions;
    float    *chi_squared_stats, *statistics;
    char     *labels[] = {
             "Exact mean",
             "Exact standard deviation",
             "Phi",
             "P",
             "Cramers V"};
    char     *stat_row_labels[] = {"Gamma", "Tau B", "Tau C", 
             "D-Row", "D-Column", "Correlation", "Spearman",
             "GK tau rows", "GK tau cols.", "U - sym.", "U - rows",
             "U - cols.", "Lambda-sym.", "Lambda-row", "Lambda-col.",
             "l-star-rows", "l-star-col.", "Lin. trend", 
             "Kruskal row", "Kruskal col.", "Kappa", "McNemar",
             "McNemar df=1"};
    char     *stat_col_labels[] = {"","statistic", "standard error",
             "std. error under Ho", "t-value testing Ho", 
             "p-value"};

    imsls_f_contingency_table (n_rows, n_columns, table,
             IMSLS_CHI_SQUARED, &df1, &chi_squared, &p_value1,
             IMSLS_LRT, &df2, &g_squared, &p_value2,
             IMSLS_EXPECTED, &expected, 
             IMSLS_CONTRIBUTIONS,
                        &chi_squared_contributions, 
             IMSLS_CHI_SQUARED_STATS, &chi_squared_stats,
             IMSLS_STATISTICS, &statistics,
             0);

    printf("Pearson chi-squared statistic     %11.4f\n", chi_squared);
    printf("p-value for Pearson chi-squared   %11.4f\n", p_value1);
    printf("degrees of freedom                %11d\n", df1);
    printf("G-squared statistic               %11.4f\n", g_squared);
    printf("p-value for G-squared             %11.4f\n", p_value2);
    printf("degrees of freedom                %11d\n", df2);

    imsls_f_write_matrix("* * * Table Values * * *\n", 4, 4,
             table,
             IMSLS_WRITE_FORMAT, "%11.1f",
             0);

    imsls_f_write_matrix("* * * Expected Values * * *\n", 5, 5,
             expected,
             IMSLS_WRITE_FORMAT, "%11.2f",
             0);
    imsls_f_write_matrix("* * * Contributions to Chi-squared* * *\n",
             5, 5,
             chi_squared_contributions,
             IMSLS_WRITE_FORMAT, "%11.2f",
             0);
    imsls_f_write_matrix("* * * Chi-square Statistics * * *\n",
             5, 1,
             chi_squared_stats,
             IMSLS_ROW_LABELS, labels,
             IMSLS_WRITE_FORMAT, "%11.4f",
             0);
    imsls_f_write_matrix("* * * Table Statistics * * *\n",
             23, 5,
             statistics,
             IMSLS_ROW_LABELS, stat_row_labels,
             IMSLS_COL_LABELS, stat_col_labels,
             IMSLS_WRITE_FORMAT, "%9.4f",
             0);
}
